@@ -2,7 +2,7 @@
  * Enhanced Seccomp x86_64 Specific Code
  *
  * Copyright (c) 2012 Red Hat <pmoore@redhat.com>
- * Author: Paul Moore <pmoore@redhat.com>
+ * Author: Paul Moore <paul@paul-moore.com>
  */
 
 /*
@@ -25,9 +25,17 @@
 
 #include "arch.h"
 #include "arch-x86_64.h"
+#include "syscalls.h"
+
+ARCH_DEF(x86_64)
 
 const struct arch_def arch_def_x86_64 = {
-	.token = AUDIT_ARCH_X86_64,
+	.token = SCMP_ARCH_X86_64,
+	.token_bpf = AUDIT_ARCH_X86_64,
 	.size = ARCH_SIZE_64,
 	.endian = ARCH_ENDIAN_LITTLE,
+	.syscall_resolve_name_raw = x86_64_syscall_resolve_name,
+	.syscall_resolve_num_raw = x86_64_syscall_resolve_num,
+	.syscall_rewrite = NULL,
+	.rule_add = NULL,
 };
